@@ -1,5 +1,5 @@
 package Statocles::Test;
-our $VERSION = '0.086';
+our $VERSION = '0.087';
 # ABSTRACT: Common test routines for Statocles
 
 use Statocles::Base;
@@ -203,15 +203,21 @@ sub test_pages {
             next;
         }
 
-        my $output = $page->render;
+        my $output;
 
-        # Handle filehandles from render
-        if ( ref $output eq 'GLOB' ) {
-            $output = do { local $/; <$output> };
+        if ( $page->has_dom ) {
+            $output = "".$page->dom;
         }
-        # Handle Path::Tiny from render
-        elsif ( Scalar::Util::blessed( $output ) && $output->isa( 'Path::Tiny' ) ) {
-            $output = $output->slurp_raw;
+        else {
+            $output = $page->render;
+            # Handle filehandles from render
+            if ( ref $output eq 'GLOB' ) {
+                $output = do { local $/; <$output> };
+            }
+            # Handle Path::Tiny from render
+            elsif ( Scalar::Util::blessed( $output ) && $output->isa( 'Path::Tiny' ) ) {
+                $output = $output->slurp_raw;
+            }
         }
 
         if ( $page->path =~ /[.](?:html|rss|atom)$/ ) {
@@ -364,7 +370,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.086
+version 0.087
 
 =head1 DESCRIPTION
 
